@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 from optparse import OptionParser
 import hipsaint
-from hipsaint.messages import HipchatMessage
+from ..messages import HipchatMessage
 
 
 def main():
@@ -30,15 +30,17 @@ def main():
                       help="Input variables from Nagios separated by |")
 
     parser.add_option("-T", "--type",
-                      dest="type",
+                      dest="msg_type",
                       default="",
-                      help="Mark if notification is from host group or service group, host|service|short-host|short-service")
+                      help="Mark if notification is from host group or service group, "
+                           "host|service|short-host|short-service")
 
     parser.add_option("-n", "--notify",
                       action="store_true",
                       default=False,
                       dest="notify",
-                      help="Whether or not this message should trigger a notification for people in the room")
+                      help="Whether or not this message should trigger a "
+                           "notification for people in the room")
 
     ### Parse command line
     (options, args) = parser.parse_args()
@@ -49,7 +51,7 @@ def main():
         parser.error('--inputs is required')
     if not options.room_id:
         parser.error('--room is required')
-    if not options.type:
+    if not options.msg_type:
         parser.error('--type is required')
     msg = HipchatMessage(**vars(options))
     msg.deliver_payload()
